@@ -1,7 +1,7 @@
 """Licensed under GPLv3, see https://www.gnu.org/licenses/"""
 
 from multiprocessing.pool import ThreadPool
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 from urllib import parse
 from urllib.parse import quote
 
@@ -43,13 +43,14 @@ class AURPackageInfo(DataType):
     pkg_license: str | None = None
     keywords: list[str] = []
     groups: list[str] = []
+    submitter: str | None = None
+    comaintainers: list[str] = []
 
     @property
     def git_url(self) -> str:
         return f'{AUR_BASE_URL}/{self.packagebase}.git'
 
-    # @TODO: type it later:
-    def __init__(self, **kwargs) -> None:  # type: ignore
+    def __init__(self, **kwargs: Any) -> None:
         for aur_api_name, pikaur_class_name in (
             ('description', 'desc', ),
             ('id', 'aur_id', ),
@@ -114,7 +115,10 @@ def aur_rpc_search_name_desc(search_query: str) -> list[AURPackageInfo]:
     if 'error' in result_json:
         raise AURError(url=url, error=result_json['error'])
     return [
-        AURPackageInfo(**{key.lower(): value for key, value in aur_json.items()})
+        AURPackageInfo(
+            **{key.lower(): value for key, value in aur_json.items()},
+            ignore_extra_properties=True
+        )
         for aur_json in result_json.get('results', [])
     ]
 
@@ -131,7 +135,10 @@ def aur_rpc_info(search_queries: list[str]) -> list[AURPackageInfo]:
     if 'error' in result_json:
         raise AURError(url=url, error=result_json['error'])
     return [
-        AURPackageInfo(**{key.lower(): value for key, value in aur_json.items()})
+        AURPackageInfo(
+            **{key.lower(): value for key, value in aur_json.items()},
+            ignore_extra_properties=True
+        )
         for aur_json in result_json.get('results', [])
     ]
 
