@@ -4,7 +4,7 @@ import os
 import shutil
 from glob import glob
 from multiprocessing.pool import ThreadPool
-from typing import Any
+from typing import TYPE_CHECKING
 
 from .args import PikaurArgs, parse_args
 from .aur import find_aur_packages, get_repo_url
@@ -56,6 +56,9 @@ from .updates import is_devel_pkg
 from .urllib import wrap_proxy_env
 from .version import VersionMatcher, compare_versions
 
+if TYPE_CHECKING:
+    from .core import SpawnArgs
+
 
 _debug = create_debug_logger('build')
 
@@ -426,6 +429,8 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         )
         if pkg_paths_spawn.returncode != 0:
             return
+        if not pkg_paths_spawn.stdout_text:
+            return
         pkg_paths = pkg_paths_spawn.stdout_text.splitlines()
         if not pkg_paths:
             return
@@ -593,7 +598,10 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                             removed_pkg_name in self._local_provided_pkgs_with_build_deps
                     ) and (
                         installed_pkg_name
-                        in self._local_provided_pkgs_with_build_deps[removed_pkg_name]
+                        in [
+                            dep.name for dep
+                            in self._local_provided_pkgs_with_build_deps[removed_pkg_name]
+                        ]
                     ):
                         deps_packages_installed.remove(installed_pkg_name)
                         deps_packages_removed.remove(removed_pkg_name)
@@ -694,7 +702,10 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 env['GNUPGHOME'] = self.build_gpgdir
 
             cmd_args = isolate_root_cmd(cmd_args, cwd=self.build_dir, env=env)
-            spawn_kwargs: dict[str, Any] = {}
+            spawn_kwargs: 'SpawnArgs' = {
+                "cwd": self.build_dir,
+                "env": {**os.environ, **env},
+            }
             if self.args.hide_build_log:
                 spawn_kwargs = {
                     "stdout": PIPE,
@@ -703,8 +714,6 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
 
             result = interactive_spawn(
                 cmd_args,
-                cwd=self.build_dir,
-                env={**os.environ, **env},
                 **spawn_kwargs
             )
             print_stdout()
