@@ -38,7 +38,9 @@ INFO_FIELDS = {
     "checkdepends": translate("Check Deps"),
     "conflicts": translate("Conflicts With"),
     "replaces": translate("Replaces"),
+    "submitter": translate("Submitter"),
     "maintainer": translate("Maintainer"),
+    "comaintainers": translate("Co-maintainers"),
     "numvotes": translate("Votes"),
     "popularity": translate("Popularity"),
     "firstsubmitted": translate("First Submitted"),
