@@ -2,7 +2,7 @@
 
 import sys
 from multiprocessing.pool import ThreadPool
-from typing import Any, Iterable, TypeVar
+from typing import Iterable, TypeVar
 
 import pyalpm
 
@@ -43,7 +43,9 @@ def filter_aur_results(
     return filtered_results
 
 
-def package_search_thread_aur(queries: list[str]) -> list[Any]:  # pylint: disable=too-many-branches
+def package_search_thread_aur(  # pylint: disable=too-many-branches
+        queries: list[str]
+) -> list[AURPackageInfo]:
     args = parse_args()
     result = {}
     if queries:
@@ -127,7 +129,7 @@ def join_search_results(
     }.values()
 
 
-def cli_search_packages(  # pylint: disable=too-many-locals
+def search_packages(  # pylint: disable=too-many-locals
         enumerated: bool = False
 ) -> list[AnyPackage]:
     refresh_pkg_db_if_needed()
@@ -182,3 +184,7 @@ def cli_search_packages(  # pylint: disable=too-many-locals
         local_pkgs_versions=result_local,
         enumerated=enumerated,
     )
+
+
+def cli_search_packages() -> None:
+    search_packages()
