@@ -1,59 +1,84 @@
 import gzip
 import json
 import socket
+from time import sleep
+from typing import Any
 from urllib import request
 from urllib.error import URLError
-from typing import Any, Dict, List
 
-from .i18n import translate
-from .pprint import print_error, print_stderr, color_line, ColorsHighlight
-from .prompt import ask_to_continue
-from .exceptions import SysExit
 from .args import parse_args
 from .config import PikaurConfig
+from .exceptions import SysExit
+from .i18n import translate
+from .pprint import ColorsHighlight, color_line, print_error, print_stderr
+from .prompt import ask_to_continue
 
 
 DEFAULT_WEB_ENCODING = 'utf-8'
+NOCONFIRM_RETRY_INTERVAL = 3
 
 
-def read_bytes_from_url(url: str, optional=False) -> bytes:
-    if parse_args().print_commands:
+def read_bytes_from_url(
+        url: str,
+        optional: bool = False,
+        autoretry: bool = True,
+) -> bytes:
+    args = parse_args()
+    if args.print_commands:
         print_stderr(
             color_line('=> ', ColorsHighlight.cyan) + f'GET {url}'
         )
     req = request.Request(url, headers={'User-Agent': 'Mozilla/5.0'})
     try:
         with request.urlopen(req) as response:  # nosec B310
-            result_bytes = response.read()
+            result_bytes: bytes = response.read()
             return result_bytes
     except URLError as exc:
         print_error(f'GET {url}')
         print_error('urllib: ' + str(exc.reason))
+        if autoretry and ask_to_continue(translate('Do you want to retry?')):  # pragma: no cover
+            if args.noconfirm:
+                print_stderr(
+                    translate('Sleeping for {} seconds...').format(
+                        NOCONFIRM_RETRY_INTERVAL
+                    )
+                )
+                sleep(NOCONFIRM_RETRY_INTERVAL)
+            return read_bytes_from_url(url, optional=optional)
         if optional:
             return b''
-        if ask_to_continue(translate('Do you want to retry?')):
-            return read_bytes_from_url(url, optional=optional)
         raise SysExit(102) from exc
 
 
-def get_unicode_from_url(url: str, optional=False) -> str:
+def get_unicode_from_url(url: str, optional: bool = False) -> str:
     result_bytes = read_bytes_from_url(url, optional=optional)
     return result_bytes.decode(DEFAULT_WEB_ENCODING)
 
 
-def get_json_from_url(url: str) -> Dict[str, Any]:
+def get_json_from_url(url: str) -> Any:
     result_json = json.loads(get_unicode_from_url(url))
     return result_json
 
 
-def get_gzip_from_url(url: str) -> str:
+def get_gzip_from_url(
+        url: str,
+        autoretry: bool = True,
+) -> str:
     result_bytes = read_bytes_from_url(url)
     try:
         decompressed_bytes_response = gzip.decompress(result_bytes)
-    except EOFError as exc:
+    except Exception as exc:
         print_error(f'GET {url}')
         print_error('urllib: ' + str(exc))
-        if ask_to_continue(translate('Do you want to retry?')):
+        if autoretry and ask_to_continue(translate('Do you want to retry?')):  # pragma: no cover
+            args = parse_args()
+            if args.noconfirm:
+                print_stderr(
+                    translate('Sleeping for {} seconds...').format(
+                        NOCONFIRM_RETRY_INTERVAL
+                    )
+                )
+                sleep(NOCONFIRM_RETRY_INTERVAL)
             return get_gzip_from_url(url)
         raise SysExit(102) from exc
     text_response = decompressed_bytes_response.decode(DEFAULT_WEB_ENCODING)
@@ -86,7 +111,7 @@ def init_proxy() -> None:
 
     http_proxy_addr = net_config.AurHttpProxy.get_str()
     https_proxy_addr = net_config.AurHttpsProxy.get_str()
-    if http_proxy_addr or https_proxy_addr:
+    if http_proxy_addr or https_proxy_addr:  # pragma: no cover
         proxies = {}
         if http_proxy_addr:
             proxies['http'] = http_proxy_addr
@@ -97,10 +122,8 @@ def init_proxy() -> None:
         request.install_opener(opener)
 
 
-def wrap_proxy_env(cmd: List[str]) -> List[str]:
-    """
-    add env with proxy to command line args
-    """
+def wrap_proxy_env(cmd: list[str]) -> list[str]:  # pragma: no cover:
+    """Add env with proxy to command line args."""
     net_config = PikaurConfig().network
     http_proxy_addr = net_config.AurHttpProxy.get_str()
     https_proxy_addr = net_config.AurHttpsProxy.get_str()
